@@ -1,5 +1,5 @@
-#ifndef __8MTL220_400_LEN1_100
-#define __8MTL220_400_LEN1_100
+#ifndef __8MTL1401_300_LEN1_50
+#define __8MTL1401_300_LEN1_50
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MTL220_400_LEN1_100_BUILDER_VERSION_MAJOR  0
-#define 8MTL220_400_LEN1_100_BUILDER_VERSION_MINOR  9
-#define 8MTL220_400_LEN1_100_BUILDER_VERSION_BUGFIX 16
-#define 8MTL220_400_LEN1_100_BUILDER_VERSION_SUFFIX ""
-#define 8MTL220_400_LEN1_100_BUILDER_VERSION        "0.9.16"
+#define 8MTL1401_300_LEN1_50_BUILDER_VERSION_MAJOR  0
+#define 8MTL1401_300_LEN1_50_BUILDER_VERSION_MINOR  9
+#define 8MTL1401_300_LEN1_50_BUILDER_VERSION_BUGFIX 16
+#define 8MTL1401_300_LEN1_50_BUILDER_VERSION_SUFFIX ""
+#define 8MTL1401_300_LEN1_50_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
+static inline result_t set_profile_8MTL1401_300_LEn1_50(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -31,7 +31,7 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
   feedback_settings.IPS = 0;
   feedback_settings.FeedbackType = FEEDBACK_ENCODER;
   feedback_settings.FeedbackFlags = FEEDBACK_ENC_TYPE_DIFFERENTIAL | FEEDBACK_ENC_REVERSE | FEEDBACK_ENC_TYPE_AUTO;
-  feedback_settings.CountsPerTurn = 300000;
+  feedback_settings.CountsPerTurn = 600000;
   result = set_feedback_settings(id, &feedback_settings);
 
   if (result != result_ok)
@@ -44,7 +44,7 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
 
   home_settings_t home_settings;
   memset((void*)&home_settings, 0, sizeof(home_settings_t));
-  home_settings.FastHome = 104;
+  home_settings.FastHome = 52;
   home_settings.uFastHome = 0;
   home_settings.SlowHome = 15;
   home_settings.uSlowHome = 0;
@@ -63,11 +63,11 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
 
   move_settings_t move_settings;
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
-  move_settings.Speed = 200;
+  move_settings.Speed = 100;
   move_settings.uSpeed = 0;
   move_settings.Accel = 4000;
   move_settings.Decel = 4000;
-  move_settings.AntiplaySpeed = 200;
+  move_settings.AntiplaySpeed = 100;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -83,11 +83,11 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
   engine_settings.NomVoltage = 1200;
-  engine_settings.NomCurrent = 1300;
-  engine_settings.NomSpeed = 400;
+  engine_settings.NomCurrent = 2200;
+  engine_settings.NomSpeed = 200;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_LIMIT_CURR | ENGINE_ACCEL_ON;
-  engine_settings.Antiplay = 23392;
+  engine_settings.Antiplay = 13392;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
   engine_settings.StepsPerRev = 2;
   result = set_engine_settings(id, &engine_settings);
@@ -154,10 +154,10 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
   edges_settings_t edges_settings;
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = BORDER_STOP_RIGHT | BORDER_STOP_LEFT;
-  edges_settings.EnderFlags = ENDER_SWAP;
-  edges_settings.LeftBorder = -1900000;
+  edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
+  edges_settings.LeftBorder = -2850000;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 1900000;
+  edges_settings.RightBorder = 2850000;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -255,8 +255,8 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
 
   control_settings_t control_settings;
   memset((void*)&control_settings, 0, sizeof(control_settings_t));
-  control_settings.MaxSpeed[0] = 20;
-  control_settings.MaxSpeed[1] = 200;
+  control_settings.MaxSpeed[0] = 100;
+  control_settings.MaxSpeed[1] = 0;
   control_settings.MaxSpeed[2] = 0;
   control_settings.MaxSpeed[3] = 0;
   control_settings.MaxSpeed[4] = 0;
@@ -411,9 +411,9 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
 
   stage_information_t stage_information;
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
-  const int8_t stage_information_Manufacturer_temp[16] = {0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t stage_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 84, 76, 50, 50, 48, 45, 52, 48, 48, 45, 76, 69, 110, 49, 45, 49, 48, 48, 0, 0, 0, 83};
+  const int8_t stage_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -427,11 +427,11 @@ static inline result_t set_profile_8MTL220_400_LEn1_100(device_t id)
 
   stage_settings_t stage_settings;
   memset((void*)&stage_settings, 0, sizeof(stage_settings_t));
-  stage_settings.LeadScrewPitch = 30;
-  const int8_t stage_settings_Units_temp[8] = {0, 109, 0, 114, 101, 101, 0, 0};
+  stage_settings.LeadScrewPitch = 0;
+  const int8_t stage_settings_Units_temp[8] = {0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
-  stage_settings.MaxSpeed = 400;
-  stage_settings.TravelRange = 400;
+  stage_settings.MaxSpeed = 0;
+  stage_settings.TravelRange = 0;
   stage_settings.SupplyVoltageMin = 0;
   stage_settings.SupplyVoltageMax = 0;
   stage_settings.MaxCurrentConsumption = 0;
