@@ -1,4 +1,4 @@
-def set_profile_8MVT188_20(lib, id):
+def set_profile_8MVT25_6(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -10,7 +10,7 @@ def set_profile_8MVT188_20(lib, id):
         FEEDBACK_NONE = 5
         FEEDBACK_EMF = 4
         FEEDBACK_ENCODER = 1
-    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_EMF
+    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_NONE
     class FeedbackFlags_:
         FEEDBACK_ENC_TYPE_BITS = 192
         FEEDBACK_ENC_TYPE_DIFFERENTIAL = 128
@@ -56,11 +56,11 @@ def set_profile_8MVT188_20(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 800
+    move_settings.Speed = 457
     move_settings.uSpeed = 0
     move_settings.Accel = 2000
     move_settings.Decel = 4000
-    move_settings.AntiplaySpeed = 1000
+    move_settings.AntiplaySpeed = 457
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,9 +73,9 @@ def set_profile_8MVT188_20(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 1
-    engine_settings.NomCurrent = 2100
-    engine_settings.NomSpeed = 2000
+    engine_settings.NomVoltage = 300
+    engine_settings.NomCurrent = 180
+    engine_settings.NomSpeed = 914
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,8 +86,8 @@ def set_profile_8MVT188_20(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON
-    engine_settings.Antiplay = 575
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_CURRENT_AS_RMS
+    engine_settings.Antiplay = 169
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -99,7 +99,7 @@ def set_profile_8MVT188_20(lib, id):
         MICROSTEP_MODE_FRAC_2 = 2
         MICROSTEP_MODE_FULL = 1
     engine_settings.MicrostepMode = MicrostepMode_.MICROSTEP_MODE_FRAC_256
-    engine_settings.StepsPerRev = 200
+    engine_settings.StepsPerRev = 20
     result = lib.set_engine_settings(id, byref(engine_settings))
 
     if result != Result.Ok:
@@ -137,7 +137,7 @@ def set_profile_8MVT188_20(lib, id):
         POWER_SMOOTH_CURRENT = 4
         POWER_OFF_ENABLED = 2
         POWER_REDUCT_ENABLED = 1
-    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_OFF_ENABLED | PowerFlags_.POWER_REDUCT_ENABLED
+    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_REDUCT_ENABLED
     result = lib.set_power_settings(id, byref(power_settings))
 
     if result != Result.Ok:
@@ -181,10 +181,10 @@ def set_profile_8MVT188_20(lib, id):
         ENDER_SW2_ACTIVE_LOW = 4
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
-    edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = 218101
+    edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
+    edges_settings.LeftBorder = -226
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 8524951
+    edges_settings.RightBorder = 10197
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -290,8 +290,8 @@ def set_profile_8MVT188_20(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 100
-    control_settings.MaxSpeed[1] = 1000
+    control_settings.MaxSpeed[0] = 45
+    control_settings.MaxSpeed[1] = 457
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
@@ -400,9 +400,9 @@ def set_profile_8MVT188_20(lib, id):
 
     emf_settings = emf_settings_t()
 
-    emf_settings.L = 0.013000000268220901
-    emf_settings.R = 2.5999999046325684
-    emf_settings.Km = 0.015599999576807022
+    emf_settings.L = 0
+    emf_settings.R = 0
+    emf_settings.Km = 0
     class BackEMFFlags_:
         BACK_EMF_KM_AUTO = 4
         BACK_EMF_RESISTANCE_AUTO = 2
@@ -445,8 +445,8 @@ def set_profile_8MVT188_20(lib, id):
 
     stage_information = stage_information_t()
 
-    stage_information.Manufacturer = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    stage_information.PartNumber = bytes([56, 77, 86, 84, 50, 53, 45, 54, 0, 48, 0, 86, 83, 83, 52, 51, 0, 53, 48, 0, 0, 0, 0, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
